@@ -1,4 +1,4 @@
-# $Id: XSH2.pm,v 2.2 2004/12/14 14:04:40 pajas Exp $
+# $Id: XSH2.pm,v 2.3 2007/01/02 22:03:23 pajas Exp $
 
 package XML::XSH2;
 
@@ -6,7 +6,7 @@ use strict;
 use vars qw(@EXPORT_OK @EXPORT @ISA $VERSION);
 
 BEGIN {
-  $VERSION   = '1.2';
+  $VERSION='2.1.0'; # VERSION TEMPLATE
   @ISA       = qw(Exporter);
   @EXPORT = qw(&xsh);
   @EXPORT_OK = @XML::XSH2::Functions::EXPORT_OK;
@@ -80,6 +80,6 @@ Petr Pajas, pajas@matfyz.cz
 
 =head1 SEE ALSO
 
-L<xsh>, L<XSH2>, L<XML::LibXML>, L<XML::XUpdate>
+L<xsh>, L<XSH2>, L<XML::XSH2::Compile>, L<XML::LibXML>, L<XML::XUpdate>
 
 =cut
